@@ -1,21 +1,20 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2015 Guillaume Gomez
 //
 
-#![allow(decimal_literal_representation)]
-
 pub mod component;
 pub mod disk;
 pub mod network;
 pub mod process;
 pub mod processor;
 pub mod system;
+pub mod users;
 
 pub use self::component::Component;
-pub use self::disk::{Disk, DiskType};
-pub use self::network::NetworkData;
+pub use self::disk::Disk;
+pub use self::network::{NetworkData, Networks};
 pub use self::process::{Process, ProcessStatus};
 pub use self::processor::Processor;
 pub use self::system::System;
