@@ -1,6 +1,6 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2015 Guillaume Gomez
 //
 
@@ -11,10 +11,11 @@ pub mod network;
 pub mod process;
 pub mod processor;
 pub mod system;
+pub mod users;
 
 pub use self::component::Component;
-pub use self::disk::{Disk, DiskType};
-pub use self::network::NetworkData;
-pub use self::process::{Process,ProcessStatus};
+pub use self::disk::Disk;
+pub use self::network::{NetworkData, Networks};
+pub use self::process::{Process, ProcessStatus};
 pub use self::processor::Processor;
 pub use self::system::System;
