@@ -1,6 +1,6 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2015 Guillaume Gomez
 //
 
@@ -9,8 +9,8 @@
 
 #[cfg(test)]
 mod tests {
-    use ::{ProcessExt, System, SystemExt};
-    use ::utils;
+    use utils;
+    use {ProcessExt, System, SystemExt};
 
     #[test]
     fn test_refresh_system() {
@@ -25,15 +25,24 @@ mod tests {
     #[test]
     fn test_refresh_process() {
         let mut sys = System::new();
-        assert!(sys.refresh_process(utils::get_current_pid().expect("failed to get current pid")));
+        assert!(
+            sys.get_processes().is_empty(),
+            "no process should be listed!"
+        );
+        sys.refresh_processes();
+        assert!(
+            sys.refresh_process(utils::get_current_pid().expect("failed to get current pid")),
+            "process not listed",
+        );
     }
 
     #[test]
     fn test_get_process() {
         let mut sys = System::new();
         sys.refresh_processes();
-        let p = sys.get_process(utils::get_current_pid().expect("failed to get current pid"))
-                   .expect("didn't find process");
+        let p = sys
+            .get_process(utils::get_current_pid().expect("failed to get current pid"))
+            .expect("didn't find process");
         assert!(p.memory() > 0);
     }
 
@@ -52,8 +61,9 @@ mod tests {
 
         let mut sys = System::new();
         sys.refresh_processes();
-        let p = sys.get_process(utils::get_current_pid().expect("failed to get current pid"))
-                   .expect("didn't find process");
+        let p = sys
+            .get_process(utils::get_current_pid().expect("failed to get current pid"))
+            .expect("didn't find process");
         p.foo(); // If this doesn't compile, it'll simply mean that the Process type
                  // doesn't implement the Send trait.
         p.bar(); // If this doesn't compile, it'll simply mean that the Process type
