@@ -1,14 +1,13 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2018 Guillaume Gomez
 //
 
 use ComponentExt;
 
 /// Dummy struct representing a component.
-pub struct Component {
-}
+pub struct Component {}
 
 impl ComponentExt for Component {
     fn get_temperature(&self) -> f32 {
@@ -26,4 +25,6 @@ impl ComponentExt for Component {
     fn get_label(&self) -> &str {
         ""
     }
+
+    fn refresh(&mut self) {}
 }
