@@ -1,22 +1,17 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2017 Guillaume Gomez
 //
 
-use ::DiskExt;
+use DiskExt;
+use DiskType;
 
-use std::path::Path;
 use std::ffi::OsStr;
-
-/// Enum containing the different handled disks types.
-#[derive(Debug, PartialEq, Clone, Copy)]
-pub enum DiskType {
-}
+use std::path::Path;
 
 /// Struct containing a disk information.
-pub struct Disk {
-}
+pub struct Disk {}
 
 impl DiskExt for Disk {
     fn get_type(&self) -> DiskType {
@@ -43,7 +38,7 @@ impl DiskExt for Disk {
         0
     }
 
-    fn update(&mut self) -> bool {
+    fn refresh(&mut self) -> bool {
         true
     }
 }
