@@ -1,19 +1,20 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2015 Guillaume Gomez
 //
 
 use std::path::Path;
+use DiskUsage;
 use Pid;
-use ::ProcessExt;
+use ProcessExt;
 
 /// Enum describing the different status of a process.
 #[derive(Clone, Copy, Debug)]
 pub struct ProcessStatus;
 
 /// Struct containing a process' information.
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct Process {
     pid: Pid,
     parent: Option<Pid>,
@@ -21,10 +22,7 @@ pub struct Process {
 
 impl ProcessExt for Process {
     fn new(pid: Pid, parent: Option<Pid>, _start_time: u64) -> Process {
-        Process {
-            pid,
-            parent,
-        }
+        Process { pid, parent }
     }
 
     fn kill(&self, _signal: ::Signal) -> bool {
@@ -63,6 +61,10 @@ impl ProcessExt for Process {
         0
     }
 
+    fn virtual_memory(&self) -> u64 {
+        0
+    }
+
     fn parent(&self) -> Option<Pid> {
         self.parent
     }
@@ -78,4 +80,8 @@ impl ProcessExt for Process {
     fn cpu_usage(&self) -> f32 {
         0.0
     }
+
+    fn disk_usage(&self) -> DiskUsage {
+        DiskUsage::default()
+    }
 }
