@@ -1,22 +1,22 @@
-// 
+//
 // Sysinfo
-// 
+//
 // Copyright (c) 2017 Guillaume Gomez
 //
 
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
-use std::fs;
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
-use std::path::{Path, PathBuf};
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
-use std::ffi::OsStr;
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
-use std::os::unix::ffi::OsStrExt;
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
 use libc::{c_char, lstat, stat, S_IFLNK, S_IFMT};
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
+use std::ffi::OsStr;
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
+use std::fs;
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
+use std::os::unix::ffi::OsStrExt;
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
+use std::path::{Path, PathBuf};
 use Pid;
 
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
 pub fn realpath(original: &Path) -> PathBuf {
     use std::mem::MaybeUninit;
 
@@ -51,7 +51,7 @@ pub fn realpath(original: &Path) -> PathBuf {
 }
 
 /* convert a path to a NUL-terminated Vec<u8> suitable for use with C functions */
-#[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))]
+#[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))]
 pub fn to_cpath(path: &Path) -> Vec<u8> {
     let path_os: &OsStr = path.as_ref();
     let mut cpath = path_os.as_bytes().to_vec();
@@ -62,9 +62,22 @@ pub fn to_cpath(path: &Path) -> Vec<u8> {
 /// Returns the pid for the current process.
 ///
 /// `Err` is returned in case the platform isn't supported.
+///
+/// ```no_run
+/// use sysinfo::get_current_pid;
+///
+/// match get_current_pid() {
+///     Ok(pid) => {
+///         println!("current pid: {}", pid);
+///     }
+///     Err(e) => {
+///         eprintln!("failed to get current pid: {}", e);
+///     }
+/// }
+/// ```
 pub fn get_current_pid() -> Result<Pid, &'static str> {
     cfg_if! {
-        if #[cfg(all(not(target_os = "windows"), not(target_os = "unknown")))] {
+        if #[cfg(not(any(target_os = "windows", target_os = "unknown", target_arch = "wasm32")))] {
             fn inner() -> Result<Pid, &'static str> {
                 unsafe { Ok(::libc::getpid()) }
             }
